==> hindent-6.1.0-57-x86_64.pkg.tar.zst: usr/share/haskell/register/hindent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hindent
version:              6.1.0
visibility:           public
id:                   hindent-6.1.0-FVp2Iv0Z95O9zhv6enJpbp
key:                  hindent-6.1.0-FVp2Iv0Z95O9zhv6enJpbp
license:              BSD-3-Clause
copyright:            2014 Chris Done, 2015 Andrew Gibiansky, 2021 Mihai Maruseac
maintainer:           Mihai Maruseac
author:
    Mihai Maruseac, Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker

stability:            Unstable
homepage:             https://github.com/mihaimaruseac/hindent
synopsis:             Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable. See the GitHub page for usage / explanation: <https://github.com/mihaimaruseac/hindent>

category:             Development
abi:                  a3199079bc5fe02aa093cdf4fe932937
exposed:              True
exposed-modules:      HIndent
hidden-modules:
    HIndent.Applicative HIndent.ByteString HIndent.CabalFile
    HIndent.CodeBlock HIndent.CommandlineOptions HIndent.Config
    HIndent.Error HIndent.Fixity HIndent.GhcLibParserWrapper.GHC.Hs
    HIndent.Language HIndent.LanguageExtension
    HIndent.LanguageExtension.Conversion
    HIndent.LanguageExtension.Types HIndent.ModulePreprocessing
    HIndent.ModulePreprocessing.CommentRelocation HIndent.Parse
    HIndent.Path.Find HIndent.Pragma HIndent.Pretty
    HIndent.Pretty.Combinators HIndent.Pretty.Combinators.Comment
    HIndent.Pretty.Combinators.Getter HIndent.Pretty.Combinators.Indent
    HIndent.Pretty.Combinators.Lineup HIndent.Pretty.Combinators.Op
    HIndent.Pretty.Combinators.Outputable
    HIndent.Pretty.Combinators.RhsSeparator
    HIndent.Pretty.Combinators.String HIndent.Pretty.Combinators.Switch
    HIndent.Pretty.Combinators.Wrap HIndent.Pretty.Import
    HIndent.Pretty.Import.Sort HIndent.Pretty.NodeComments
    HIndent.Pretty.Pragma HIndent.Pretty.SigBindFamily
    HIndent.Pretty.Types HIndent.Printer Paths_hindent

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hindent-6.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hindent-6.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hindent-6.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hindent
hs-libraries:         HShindent-6.1.0-FVp2Iv0Z95O9zhv6enJpbp
depends:
    Cabal-3.8.1.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.7.1 exceptions-0.10.5 filepath-1.4.2.2 ghc-9.4.8
    ghc-boot-9.4.8 ghc-lib-parser-ex-9.4.0.0-GWlTTdcEtmrIANzz562teb
    monad-loops-0.4.3-KaRiS5mJjkQ1zBkxxbNC2Z mtl-2.2.2
    optparse-applicative-0.18.1.0-7AikOdbhtzBKh97m9q2q6o
    path-0.9.5-A9z9fR8KvJ4LScQXHVsRJ3
    path-io-1.8.2-BesO8f6gaDw3FHxt7kE5T2
    regex-tdfa-1.3.2.5-Gv6LsF4EJj23ouLVTe9nXQ
    split-0.2.5-Dujwwofvw7aEFmjRmWhj9Q syb-0.7.3-6hZpCMnOgIw3sb7LbwnFLW
    transformers-0.5.6.2 unicode-show-0.1.1.1-LBWmG4OCFBNIHVw9oesuiJ
    utf8-string-1.0.2-4OrQf1vZkgOAJqnDO7nv41
    yaml-0.11.11.2-Cd6mVxIORdjI2M1tHsruv6

haddock-interfaces:   /usr/share/doc/hindent/html/hindent.haddock
haddock-html:         /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-hindent-z-hindent-internal
version:              6.1.0
package-name:         hindent
lib-name:             hindent-internal
id:                   hindent-6.1.0-Cr20lxxG7ChsLdYPVfBgJ-hindent-internal
key:                  hindent-6.1.0-Cr20lxxG7ChsLdYPVfBgJ-hindent-internal
license:              BSD-3-Clause
copyright:            2014 Chris Done, 2015 Andrew Gibiansky, 2021 Mihai Maruseac
maintainer:           Mihai Maruseac
author:
    Mihai Maruseac, Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker

stability:            Unstable
homepage:             https://github.com/mihaimaruseac/hindent
synopsis:             Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable. See the GitHub page for usage / explanation: <https://github.com/mihaimaruseac/hindent>

category:             Development
abi:                  225fa3879e2b7cda1596b9ca5f1c9140
exposed-modules:      HIndent.Internal.Test.Markdone
hidden-modules:       Paths_hindent
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hindent-6.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hindent-6.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hindent-6.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hindent
hs-libraries:         HShindent-6.1.0-Cr20lxxG7ChsLdYPVfBgJ-hindent-internal
depends:
    Cabal-3.8.1.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    deepseq-1.4.8.0 directory-1.3.7.1 exceptions-0.10.5
    filepath-1.4.2.2 ghc-9.4.8 ghc-boot-9.4.8
    ghc-lib-parser-ex-9.4.0.0-GWlTTdcEtmrIANzz562teb
    monad-loops-0.4.3-KaRiS5mJjkQ1zBkxxbNC2Z mtl-2.2.2
    optparse-applicative-0.18.1.0-7AikOdbhtzBKh97m9q2q6o
    path-0.9.5-A9z9fR8KvJ4LScQXHVsRJ3
    path-io-1.8.2-BesO8f6gaDw3FHxt7kE5T2
    regex-tdfa-1.3.2.5-Gv6LsF4EJj23ouLVTe9nXQ
    split-0.2.5-Dujwwofvw7aEFmjRmWhj9Q syb-0.7.3-6hZpCMnOgIw3sb7LbwnFLW
    transformers-0.5.6.2 unicode-show-0.1.1.1-LBWmG4OCFBNIHVw9oesuiJ
    utf8-string-1.0.2-4OrQf1vZkgOAJqnDO7nv41
    yaml-0.11.11.2-Cd6mVxIORdjI2M1tHsruv6

haddock-interfaces:   /usr/share/doc/hindent/html/hindent.haddock
haddock-html:         /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hindent-6.1.0-58-x86_64.pkg.tar.zst: usr/share/haskell/register/hindent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hindent
version:              6.1.0
visibility:           public
id:                   hindent-6.1.0-EeJbcMFY0FR8fbQgnXgx4H
key:                  hindent-6.1.0-EeJbcMFY0FR8fbQgnXgx4H
license:              BSD-3-Clause
copyright:            2014 Chris Done, 2015 Andrew Gibiansky, 2021 Mihai Maruseac
maintainer:           Mihai Maruseac
author:
    Mihai Maruseac, Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker

stability:            Unstable
homepage:             https://github.com/mihaimaruseac/hindent
synopsis:             Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable. See the GitHub page for usage / explanation: <https://github.com/mihaimaruseac/hindent>

category:             Development
abi:                  424cb73b04ec49127db39ac3b944cd77
exposed:              True
exposed-modules:      HIndent
hidden-modules:
    HIndent.Applicative HIndent.ByteString HIndent.CabalFile
    HIndent.CodeBlock HIndent.CommandlineOptions HIndent.Config
    HIndent.Error HIndent.Fixity HIndent.GhcLibParserWrapper.GHC.Hs
    HIndent.Language HIndent.LanguageExtension
    HIndent.LanguageExtension.Conversion
    HIndent.LanguageExtension.Types HIndent.ModulePreprocessing
    HIndent.ModulePreprocessing.CommentRelocation HIndent.Parse
    HIndent.Path.Find HIndent.Pragma HIndent.Pretty
    HIndent.Pretty.Combinators HIndent.Pretty.Combinators.Comment
    HIndent.Pretty.Combinators.Getter HIndent.Pretty.Combinators.Indent
    HIndent.Pretty.Combinators.Lineup HIndent.Pretty.Combinators.Op
    HIndent.Pretty.Combinators.Outputable
    HIndent.Pretty.Combinators.RhsSeparator
    HIndent.Pretty.Combinators.String HIndent.Pretty.Combinators.Switch
    HIndent.Pretty.Combinators.Wrap HIndent.Pretty.Import
    HIndent.Pretty.Import.Sort HIndent.Pretty.NodeComments
    HIndent.Pretty.Pragma HIndent.Pretty.SigBindFamily
    HIndent.Pretty.Types HIndent.Printer Paths_hindent

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hindent-6.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hindent-6.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hindent-6.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hindent
hs-libraries:         HShindent-6.1.0-EeJbcMFY0FR8fbQgnXgx4H
depends:
    Cabal-3.8.1.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.7.1 exceptions-0.10.5 filepath-1.4.2.2 ghc-9.4.8
    ghc-boot-9.4.8 ghc-lib-parser-ex-9.4.0.0-KbgqXI7NP6JDyvNNxv2kk5
    monad-loops-0.4.3-KaRiS5mJjkQ1zBkxxbNC2Z mtl-2.2.2
    optparse-applicative-0.18.1.0-I864cMO0U1ABRAZwcl7eB7
    path-0.9.5-8bqO3CzrtxSJbtUdi1yYfm
    path-io-1.8.2-qT4PaXoZ3G6fBkdq5DxGb
    regex-tdfa-1.3.2.5-3jfIfS23fhoC4PyiafLhmq
    split-0.2.5-Dujwwofvw7aEFmjRmWhj9Q syb-0.7.3-CwqNo0h5dXa2Bf4xbRg7w6
    transformers-0.5.6.2 unicode-show-0.1.1.1-IhSsJS5yYvAK1I4UXWZGRl
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    yaml-0.11.11.2-86vh7a5da508VmYUUJ1GSC

haddock-interfaces:   /usr/share/doc/hindent/html/hindent.haddock
haddock-html:         /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-hindent-z-hindent-internal
version:              6.1.0
package-name:         hindent
lib-name:             hindent-internal
id:                   hindent-6.1.0-5voN4bXMIbCKFQBUq3WnTM-hindent-internal
key:                  hindent-6.1.0-5voN4bXMIbCKFQBUq3WnTM-hindent-internal
license:              BSD-3-Clause
copyright:            2014 Chris Done, 2015 Andrew Gibiansky, 2021 Mihai Maruseac
maintainer:           Mihai Maruseac
author:
    Mihai Maruseac, Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker

stability:            Unstable
homepage:             https://github.com/mihaimaruseac/hindent
synopsis:             Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable. See the GitHub page for usage / explanation: <https://github.com/mihaimaruseac/hindent>

category:             Development
abi:                  fa2291740f25f3f2bb6be89ff32041d3
exposed-modules:      HIndent.Internal.Test.Markdone
hidden-modules:       Paths_hindent
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hindent-6.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hindent-6.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hindent-6.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hindent
hs-libraries:         HShindent-6.1.0-5voN4bXMIbCKFQBUq3WnTM-hindent-internal
depends:
    Cabal-3.8.1.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    deepseq-1.4.8.0 directory-1.3.7.1 exceptions-0.10.5
    filepath-1.4.2.2 ghc-9.4.8 ghc-boot-9.4.8
    ghc-lib-parser-ex-9.4.0.0-KbgqXI7NP6JDyvNNxv2kk5
    monad-loops-0.4.3-KaRiS5mJjkQ1zBkxxbNC2Z mtl-2.2.2
    optparse-applicative-0.18.1.0-I864cMO0U1ABRAZwcl7eB7
    path-0.9.5-8bqO3CzrtxSJbtUdi1yYfm
    path-io-1.8.2-qT4PaXoZ3G6fBkdq5DxGb
    regex-tdfa-1.3.2.5-3jfIfS23fhoC4PyiafLhmq
    split-0.2.5-Dujwwofvw7aEFmjRmWhj9Q syb-0.7.3-CwqNo0h5dXa2Bf4xbRg7w6
    transformers-0.5.6.2 unicode-show-0.1.1.1-IhSsJS5yYvAK1I4UXWZGRl
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    yaml-0.11.11.2-86vh7a5da508VmYUUJ1GSC

haddock-interfaces:   /usr/share/doc/hindent/html/hindent.haddock
haddock-html:         /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
